@@ -6,7 +6,7 @@ set -eux
 #TAG=$(git tag -l --points-at HEAD)
 
 # Add Qt binaries to path
-PATH=/usr/local/opt/qt/bin/:${PATH}
+PATH=/usr/local/opt/qt@5/bin/:${PATH}
 
 ( cd build
   # macdeployqt does not copy symlinks over.
@@ -16,15 +16,19 @@ PATH=/usr/local/opt/qt/bin/:${PATH}
   mkdir -p nheko.app/Contents/Frameworks
   find "${ICU_LIB}" -type l -name "*.dylib" -exec cp -a -n {} nheko.app/Contents/Frameworks/ \; || true
 
-  sudo macdeployqt nheko.app -dmg -always-overwrite
+  macdeployqt nheko.app -dmg -always-overwrite -qmldir=../resources/qml/
 
   user=$(id -nu)
-  sudo chown "${user}" nheko.dmg
+  chown "${user}" nheko.dmg
   mv nheko.dmg ..
 )
 
 dmgbuild -s ./.ci/macos/settings.json "Nheko" nheko.dmg
 
-if [ ! -z "$VERSION" ]; then
+VERSION=${CI_COMMIT_SHORT_SHA}
+
+if [ -n "$VERSION" ]; then
     mv nheko.dmg "nheko-${VERSION}.dmg"
+    mkdir artifacts
+    cp "nheko-${VERSION}.dmg" artifacts/
 fi
